@@ -7,20 +7,24 @@ import cls_client
 from .core import Combine
 from .dev import Watcher, Server
 from .exceptions import BuildError
+from . import __version__
 
 
 cls_client.set_project_key("cls_pk_QFp5bJFR1RXauHdvRUDpDngE")
 cls_client.set_project_slug("combine")
-cls_client.set_noninteractive_tracking(
-    enabled=True,
-    is_noninteractive="CI" in os.environ,
-)
+cls_client.set_version(__version__)
+cls_client.set_noninteractive_tracking_enabled(True)
 
 
-@click.group()
+@click.group(invoke_without_command=True)
+@click.option("--version", "-v", is_flag=True, help="Show version and exit.")
 @click.pass_context
-def cli(ctx):
-    pass
+def cli(ctx, version):
+    if not ctx.invoked_subcommand:
+        if version:
+            click.echo(__version__)
+        else:
+            click.echo(ctx.get_help())
 
 
 @cli.command()
@@ -28,7 +32,10 @@ def cli(ctx):
 @click.option("--env", default="production")
 @click.option("--var", multiple=True, default=[])
 @click.pass_context
-@cls_client.track_command(include_kwargs=["check", "env"], include_env=["NETLIFY"])
+@cls_client.track_command(
+    include_kwargs=["check", "env"],
+    include_env=["NETLIFY", "CIRCLECI", "TRAVIS", "GITLAB_CI", "GITHUB_ACTIONS", "CI"],
+)
 def build(ctx, check, env, var):
     variables = dict(x.split("=") for x in var)
     config_path = os.path.abspath("combine.yml")
